/*
 *	atom.h
 *
 *	This file defines the atom class.
 *
 *	(C) Copyright 1994-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef	_OPaC_ATOM_H_
#define	_OPaC_ATOM_H_

#ifndef _OPaC_OPEXPORT_H_
#include <OPaC/opexport.h>
#endif

OP_INTERFACE (atom.h);

/****************************************************************/

extern inline Bool operator == (OPStringIn a, OPAtomIn b) { return (b == a) ? TRUE : FALSE; }
extern inline Bool operator == (const LatinChar* a, OPAtomIn b) { return (b == a) ? TRUE : FALSE; }
extern inline Bool operator == (const UnicodeChar* a, OPAtomIn b) { return (b == a) ? TRUE : FALSE; }
extern inline Bool operator != (OPAtomIn a, OPStringIn b) { return (a == b) ? FALSE : TRUE; }
extern inline Bool operator != (OPStringIn a, OPAtomIn b) { return (a == b) ? FALSE : TRUE; }
extern inline Bool operator != (OPAtomIn a, const LatinChar* b) { return (a == b) ? FALSE : TRUE; }
extern inline Bool operator != (const LatinChar* a, OPAtomIn b) { return (a == b) ? FALSE : TRUE; }
extern inline Bool operator != (OPAtomIn a, const UnicodeChar* b) { return (a == b) ? FALSE : TRUE; }
extern inline Bool operator != (const UnicodeChar* a, OPAtomIn b) { return (a == b) ? FALSE : TRUE; }

/****************************************************************/

#define OP_ATOM_HASH	211						//	current atom manager hash value

/*
 *	This class provides an Atom representation. An atom
 *	corresponds to an index into an table maintained by
 *	the OPaC Atom Manager class.
 */

class OP_PUBLIC OPAtom : public OPText
{
	friend class OPString;
	friend class OPStringRef;
	friend class OPStorage;
	
	friend Bool operator == (OPAtomIn atom, OPStringIn string);

protected:
	static OPAtom*		table[OP_ATOM_HASH];	//	atom hash table
	static OPMemZone*	zone;					//	reference to Atom's memory zone
	static Bool			is_zone_ok;				//	TRUE => zone has been initialised
	
	OPAtomRef			self;					//	ourselves...
	OPAtom*				next;					//	next atom with same hash value
	LatinChar*			text;					//	pointer to buffer containing atom name
	
protected:
	OPAtom ();
	virtual ~ OPAtom ();
	
	virtual void StoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	virtual void RestoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	
	virtual const LatinChar* ReturnQuickLatin () const;	/* OVERRIDDEN */
	virtual const UnicodeChar* ReturnQuickUnicode () const;/* OVERRIDDEN */
	
	//	Inserting an atom into the hash table is done simply by using one of
	//	the SetName methods. These get called by the reference class.
	
	virtual void SetName (OPStringIn name);
	virtual void SetName (const LatinChar* name);
	virtual void SetName (const UnicodeChar* name);
	
	virtual LatinChar* AllocText (Count len);
	virtual void SetText (LatinChar* name);
	
	static OPAtom* NewAtom ();
	static OPAtom* FindAtom (OPStringIn name);
	static OPAtom* FindAtom (const LatinChar* name);
	static OPAtom* FindAtom (const UnicodeChar* name);
	static Count   Hash (const LatinChar* name, Count num);
	
public:
	virtual OPStringRef ReturnString () const;			/* OVERRIDDEN */
	virtual Bool SetString (OPStringIn text);			/* OVERRIDDEN */
	
    //	Overridden methods, inherited from the OPObject class :
    
	virtual Count ComputeHashValue (Count num) const;	/* OVERRIDDEN */
	virtual int CompareWith (OPObjectIn object) const;	/* OVERRIDDEN */
	
	static void Initialise ();
	static void Kill ();
	
	OP_DEFINE_CLASS_SPECIAL_REF (OPAtom, OPText);
};

/****************************************************************/

#endif /* _OPaC_ATOM_H_ */
