/*
 *	lookcolor.h
 *
 *	Defines the look manager colors.
 *
 *	(C) Copyright 1994-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef	_OPaC_LOOKCOLOR_H_
#define	_OPaC_LOOKCOLOR_H_

/****************************************************************/

/*
 *	The OPaC Look Manager provides a color data base with
 *	RGB component definitions for the most commonly used
 *	colors.
 *	
 *	These colors can be accessed using either their atomic
 *	name or their index into the data base, which will be
 *	faster !
 */

enum OPLookColor
{
	OP_COLOR_WHITE			= 0,				//	white (usually a real white)
	OP_COLOR_LGRAY			= 1,				//	light gray (usually 25% black)
	OP_COLOR_DGRAY			= 2,				//	dark gray (usually 50% black)
	OP_COLOR_BLACK			= 3,				//	black (usually a real black)
	OP_COLOR_BACKGROUND		= 4,				//	color of window background
	OP_COLOR_WIDGET_BACK	= 5,				//	color of widget background (eg. scroller background)
	OP_COLOR_WIDGET_FORE	= 6,				//	color of widget foreground (eg. button foreground)
	
	OP_COLOR_PSY_DANGER		= 10,				//	psychological color expressing danger
	OP_COLOR_PSY_WARNING	= 11,				//	psychological color expressing prudence
	OP_COLOR_PSY_SAFE		= 12,				//	psychological color expressing safety
	
	OP_COLOR_VIEW_NORMAL	= 20,				//	color of an enabled view
	OP_COLOR_VIEW_DIM		= 21,				//	color of a disabled view
	OP_COLOR_VIEW_ACTIVE	= 22,				//	color showing keyboard focus
	OP_COLOR_VIEW_DRAGGING	= 23,				//	color showing current drag source
	OP_COLOR_VIEW_DROPPING	= 24,				//	color showing current drop destination
	OP_COLOR_VIEW_CURSOR	= 25,				//	color used by a view's cursor
	OP_COLOR_VIEW_HILITE	= 26,				//	color used to replace black when highlighting
	OP_COLOR_VIEW_CONNECT	= 27,				//	color showing current connection destination
	
	OP_COLOR_HILITE_CLICK	= 30,				//	color used to highlight on click
	OP_COLOR_HILITE_SELECT	= 31,				//	color used to highlight on selection
	OP_COLOR_HILITE_ACTIVE	= 32,				//	color used to actively highlight
	
	OP_COLOR_UI_SELECT		= 40,				//	color used to draw user interface selections
	OP_COLOR_UI_SEL_ACTIVE	= 41,				//	color used to draw the active selection

	OP_COLOR_TOOLTIP_BACK	= 50,				//	color used for the tool tip background
	OP_COLOR_TOOLTIP_FRAME	= 51,				//	color used for the tool tip frame
	OP_COLOR_TOOLTIP_TEXT	= 52,				//	color used for the tool tip text
	
	OP_COLOR_MAX			= 52,
	OP_COLOR_NONE			= -1
};

#define	OP_COLOR_NUM	( ((Card32)(OP_COLOR_MAX)) + 1)

OP_TYPEENUM (OPLookColor);

/****************************************************************/

#endif /* _OPaC_LOOKCOLOR_H_ */
