/*
 *	scrview.h
 *
 *	The Scroll View is used to hold a set of views, which may be scrolled
 *	around on the screen.
 *
 *	(C) Copyright 1994-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef _OPaC_SCRVIEW_H_
#define	_OPaC_SCRVIEW_H_

#ifndef _OPaC_OPEXPORT_H_
#include <OPaC/opexport.h>
#endif

OP_INTERFACE (scrview.h);

#ifndef _OPaC_CONTROL_H_
#include <OPaC/control.h>
#endif

/****************************************************************/

/*
 *	Scroll View class :
 */

class OP_PUBLIC OPScrollView : public OPControl
{
	
private:
	static Bool			name_init_ok;			//	TRUE => names have been initialised :
	static OPAtomRef	name_value;				//	- query name "VisibleValue"
	static OPAtomRef	name_ratio;				//	- query name "VisibleRatio"
	static OPAtomRef	do_display;				//	- target "Display"
	static OPAtomRef	do_scroll;				//	- target "Scroll"

protected:
	OPObjectRef			h_scroller;				//	horizontal scroller (or any other object)
	OPObjectRef			v_scroller;				//	vertical scroller (or any other object)
	
private:
	Real				x_offset_ratio;			//	0.0 => left side, 1.0 => right side
	Real				y_offset_ratio;			//	0.0 => upper side, 1.0 => lower side
	
	OPRelCoord			x_offset;				//	horizontal offset in points
	OPRelCoord			y_offset;				//	vertical offset in points
	
	OPCoord				width;					//	width (may be very wide)
	OPCoord				height;					//	height (may be very high)
	
protected:
	OPScrollView ();
	virtual ~ OPScrollView ();
	
	virtual void StoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	virtual void RestoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	
	virtual void ScrollBy (OPRelCoord dx, OPRelCoord dy);
	virtual void ScrollRatioChanged ();
	
public:
	virtual void Delete ();								/* OVERRIDDEN */
	
	virtual void SetOffset (Real x, Real y);
	virtual void SetTopLeft (OPRelCoord x, OPRelCoord y);
	virtual void SetTotalSize (OPCoord width, OPCoord height);
	
	virtual void SetHScroller (OPObjectIn scr);
	virtual void SetVScroller (OPObjectIn scr);
	
	
	//	Observers exported for run-time binding :
	
	virtual void Scroll (OPObjectIn object, Card32 id);
	
	
	//	Overloaded methods :
	
	virtual void SetOrigin (OPCoord x, OPCoord y);			/* OVERRIDDEN */
	virtual void SetSize (OPCoord dx, OPCoord dy);			/* OVERRIDDEN */
	virtual void ChangeOrigin (OPCoord dx, OPCoord dy);		/* OVERRIDDEN */
	virtual void ChangeSize (OPCoord dx, OPCoord dy);		/* OVERRIDDEN */
	virtual void ChangeGeometry (OPRectIn box);				/* OVERRIDDEN */
	virtual Bool WouldAcceptMain () const;					/* OVERRIDDEN */
	virtual void BecomeMain (Bool clicked);					/* OVERRIDDEN */
	virtual void ResignMain ();								/* OVERRIDDEN */
	
	virtual void Draw (OPGrailPortIn, OPRectIn, OPDrawOp = OP_DRAW_ALL);/* OVERRIDDEN */
	
	OP_DEFINE_CLASS (OPScrollView, OPControl);
};

#endif /* _OPaC_SCRVIEW_H_ */

