/*
 *	selview.h
 *
 *	The Selection View is used to highilight the views which have been selected
 *	by the user interface builder.
 *
 *	(C) Copyright 1994-1997, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef _OPaC_SELVIEW_H_
#define	_OPaC_SELVIEW_H_

#ifndef _OPaC_OPEXPORT_H_
#include <OPaC/opexport.h>
#endif

OP_INTERFACE (selview.h);

#ifndef _OPaC_CONTROL_H_
#include <OPaC/control.h>
#endif

/****************************************************************/

/*
 *	The Selection View will be used to highlight and edit
 *	the views at run-time.
 */

class OP_PUBLIC OPSelView : public OPControl
{
	
private:
	OPViewRef			view;				//	selected view
	OPObjectRef			object;				//	selected object (if not the view)
	
	Card32				corner_num;			//	corner number
	OPRelCoord			dx, dy;
	OPObjectRef			builder;			//	builder interface
	
protected:
	OPSelView ();
	virtual ~ OPSelView ();
	
	virtual void StoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	virtual void RestoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	
	virtual void NotifySelectBuilder (OPAtomIn action = OPAtomNull);
	virtual void NotifyDeselectBuilder ();
	
public:
	virtual void Delete ();								/* OVERRIDDEN */
	
	virtual Bool BeginSelection (OPViewIn view);
	virtual void EndSelection ();
	
	virtual Bool CommitUIEdit (OPObjectIn object);
	
	virtual const OPViewRef& ReturnSelectedView () const;
	virtual const OPObjectRef& ReturnSelectedObject () const;
	
	//	Inherited methods
	
	virtual void BecomeMain (Bool clicked);				/* OVERRIDDEN */
	virtual void ResignMain ();							/* OVERRIDDEN */
	
	virtual Bool Detect (OPCoord x, OPCoord y, OPViewOut view);	/* OVERRIDDEN */
	virtual void Draw (OPGrailPortIn, OPRectIn, OPDrawOp = OP_DRAW_ALL);/* OVERRIDDEN */
	
	virtual void ButtonPress (OPEventIn ev);			/* OVERRIDDEN */
	virtual void ButtonRelease (OPEventIn ev);			/* OVERRIDDEN */
	virtual void DragNotify (OPEventIn event);			/* OVERRIDDEN */
	
	virtual void KeyDown (OPEventIn event);				/* OVERRIDDEN */
	
	OP_DEFINE_CLASS (OPSelView, OPControl);
};

#endif /* _OPaC_SELVIEW_H_ */
