/*
 *	time.h
 *
 *	Time representation and handling class.
 *
 *	(C) Copyright 1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef _OPaC_TIME_H_
#define _OPaC_TIME_H_

#include <OPaC/opexport.h>

/****************************************************************/

/*
 *	Time representation class. The time is represented with a
 *	millisecond resolution.
 */

class OP_PUBLIC OPTime : public OPObject
{
protected:
	Int32				day;				//	Gregorian day
	Card32				time;				//	time in milliseconds in given day
	
protected:
	OPTime ();
	virtual ~ OPTime ();
	
	virtual void StoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	virtual void RestoreInstance (OPStorageIn storage);	/* OVERRIDDEN */
	
public:
	virtual Bool SetDate (Count day, Count month, Count year);
	virtual Bool GetDate (CountOut day, CountOut month, CountOut year) const;
	
	virtual Bool SetTime (Count h, Count m, Count s, Count ms = 0);
	virtual Bool GetTime (CountOut h, CountOut m, CountOut s) const;
	virtual Bool GetTime (CountOut h, CountOut m, CountOut s, CountOut ms) const;
	
	virtual Count ReturnDayOfWeek () const;
	
	//	You can manipulate time spans by using the "absolute time" representation, which
	//	denotes the number of milliseconds elapsed since 15 October 1582 (date when the
	//	Gregorian calendar came into effect).
	
	virtual Bool SetAbsTime (Int64 time);
	virtual Int64 ReturnAbsTime () const;
	
	static Int64 DateTimeToAbsTime (Count day, Count month, Count year, Count h, Count m, Count s, Count ms = 0);
	static void  AbsTimeToDateTime (Int64 a, CountOut day, CountOut month, CountOut year, CountOut h, CountOut m, CountOut s);
	static void  AbsTimeToDateTime (Int64 a, CountOut day, CountOut month, CountOut year, CountOut h, CountOut m, CountOut s, CountOut ms);
	
	//	The day of week is represented by 0 = Sunday, 1 = Monday, etc...
	
	static Count AbsTimeToDayOfWeek (Int64 a);
	
	OP_DEFINE_CLASS (OPTime, OPObject);
};

/****************************************************************/

#endif /* _OPaC_TIME_H_ */
