/*
 *	xtsmartsrc.h
 *
 *	OPaC Extension: Smart Data Source provider.
 *
 *	(C) Copyright 1997-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef _OPaC_XTSMARTSRC_H_
#define	_OPaC_XTSMARTSRC_H_

#ifndef _OPaC_OPEXPORT_H_
#include <OPaC/opexport.h>
#endif

/****************************************************************/

/*
 *	OPaC Extension: the Smart Data Source provides data
 *	coming from other objects.
 */

class OP_PUBLIC OPxSmartSource
{
	
protected:
	OPObjectArray		query_roots;			//	roots or objects to query
	OPTextArray			query_names;			//	paths to value or names of value
	OPValueArray		values;					//	cache for the resulting values
	
	Bool				is_cache_ok;			//	TRUE => values in the cache are valid
	Bool				is_cache_volatile;		//	TRUE => always refresh the cache
	
	Count				max_num;				//	0 => no maximum (set by sub-class)
	Count				num;					//	current number of values
	
protected:
	OPxSmartSource ();
	virtual ~ OPxSmartSource ();
	
	virtual void StoreInstance (OPStorageIn storage);
	virtual void RestoreInstance (OPStorageIn storage);
	
	virtual void UpdateInternal ();
	virtual void DoUpdate ();					//	override this in the subclasses
	virtual void Cleanup ();
	
public:
	virtual Bool InitValueByName (Count index, OPObjectIn obj, OPAtomIn name);
	virtual Bool InitValueByPath (Count index, OPObjectIn root, OPStringIn path);
	virtual Bool SetNthValue (Count index, OPValueIn value);
	virtual Bool GetNthValue (Count index, OPValueOut value) const;
	
	Bool InitValueByName (OPObjectIn obj, OPAtomIn name)	{ return this->InitValueByName (0, obj, name); }
	Bool InitValueByPath (OPObjectIn root, OPStringIn path)	{ return this->InitValueByPath (0, root, path); }
	
	virtual void UpdateCache ();
	virtual void FlushCache ();
	virtual void EnableCache (Bool mode = TRUE);
};

/****************************************************************/

#endif /* _OPaC_XTSMARTSRC_H_ */
