/*
 *	maininit.cxx
 *
 *	System independent main initialisation. This is called by
 *	the application's "main" (or an equivalent).
 *
 *	(C) Copyright 1994-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#include <stdio.h>
#include <OPaC/app.h>
#include <OPaC/grail.h>
#include <OPaC/lookman.h>
#include <OPaC/new.h>

extern void OPaC_MainInit ();


void
OPaC_MainInit ()
{
	remove ("dbgmem.txt");
	
	OPMemZone::Initialise ();
	OPAtom::Initialise ();
	OPClassMan::Initialise ();

	//	Setup color and font managers.

	OPColorManRef color_man = OP_NEW (OPColorMan);
	OPFontManRef  font_man  = OP_NEW (OPFontMan);
	
	OPColorMan::InitSystemColorMan (color_man);
	OPFontMan::InitSystemFontMan (font_man);
	OPLookMan::Initialise ();
	
	//	Setup application object.

	OPAppRef app = (OPAppRef) OPClassMan::New ("App", OPaC_app_zone, __LINE__, __FILE__);
	OPApp::Initialise (app);
	
	OPLookMan::Current ()->SelectCursor (OP_CURSOR_NORMAL);
	
	app->Initialise ();
	app->MainEventLoop ();

	OPApp::Kill ();
	OPLookMan::Kill ();
	OPFontMan::KillSystemFontMan ();
	OPColorMan::KillSystemColorMan ();
	
	color_man = 0;
	font_man  = 0;

	OPClassMan::Kill ();
	OPAtom::Kill ();
	OPMemZone::Kill ();
}

