/*
 *	dlinkviewer.h
 *
 *	The data link viewer is a tool which allows to inspect the
 *	links established between source data fields and target data
 *	fields.
 *
 *	(C) Copyright 1997-1998, Pierre ARNAUD, OPaC bright ideas
 *		CH-1437 SUSCEVAZ, Switzerland. All rights reserved.
 */

/******************************************************************************

  This file is part of the OPaC class library ("OPaC").

  OPaC is distributed with NO WARRANTY OF ANY KIND.  No author or distributor
  accepts any responsibility for the consequences of using it, or for whether
  it serves any particular purpose or works at all, unless he or she says so
  in writing. Refer to the OPaC Free Public License (the "License") for full
  details.

  Every copy of OPaC must include a copy of the License, normally in a plain
  ASCII text file named PUBLIC. The License grants you the right to copy,
  modify and redistribute OPaC, but only under certain conditions described
  in the License. The copyright notice and this notice must be preserved on
  all copies.

******************************************************************************/

#ifndef _DLINKVIEWER_H_
#define _DLINKVIEWER_H_

#include <OPaC/dbscrlist.h>
#include <OPaC/opexport.h>
#include <OPaC/view.h>

/****************************************************************/

APP_EXPORT_CLASS (OPDataLinkViewer);

/****************************************************************/

APP_DEFINE_REF (OPDataLinkViewer, OPView);

/****************************************************************/

class OPDataLinkViewer : public OPView
{

private:
	OPDBScrollListRef	view_source;			//	list of source data fields
	OPDBScrollListRef	view_target;			//	list of target data fields
	
	OPButtonRef			button_disconnect;		//	button used to disconnect a target
	Count				source_selected;		//	selected source
	
	OPAtomRef			source_name;
	OPAtomRef			notifier_name;
	OPAtomRef			target_name;
	
	OPObjectRef			object;					//	object being inspected
	
protected:
	OPDataLinkViewer ();
	virtual ~ OPDataLinkViewer ();
	
	virtual Bool UpdateSelectedInfo ();
	
public:
	virtual void Initialise (OPObjectIn object, OPStringIn title_source, OPStringIn title_target);
	
	virtual Bool GetSelectedSource (OPAtomOut field, OPAtomOut notifier);
	virtual Bool GetSelectedTarget (OPAtomOut field);
	
	virtual Bool Update ();
	virtual Bool SourceCellActivated ();
	virtual Bool TargetCellActivated ();
	virtual Bool DisconnectTarget ();
	
	APP_DEFINE_CLASS (OPDataLinkViewer, OPView);
};

/****************************************************************/

#endif /* _DLINKVIEWER_H_ */
